using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using NetworkResurrector.Api.Application.Services.Abstractions;
using NetworkResurrector.Api.Domain.Models.InternalNotifications;
using System.Threading.Tasks;

namespace NetworkResurrector.Api.Controllers
{
    [ApiController]
    [Authorize]
    [Route("api/realtime-notifications")]
    public class RealtimeNotificationsController : ControllerBase
    {
        private readonly IMessageHubPublisher _messageHubPublisher;
        private readonly ILogger<RealtimeNotificationsController> _logger;

        public RealtimeNotificationsController(IMessageHubPublisher messageHubPublisher, ILogger<RealtimeNotificationsController> logger)
        {
            _messageHubPublisher = messageHubPublisher;
            _logger = logger;
        }

        [HttpPost("broadcast")]
        public async Task<IActionResult> Broadcast([FromBody] MessageModel message)
        {
            await _messageHubPublisher.Broadcast(message);
            return Ok();
        }

        [HttpPost("message-to-client")]
        public async Task<IActionResult> SendMessageToClient([FromBody] MessageModel message)
        {
            await _messageHubPublisher.Send(message);
            return Ok();
        }

        [HttpPost("message-to-user")]
        public async Task<IActionResult> SendMessageToUser([FromBody] MessageModel message)
        {
            await _messageHubPublisher.SendToUser(message);
            return Ok();
        }
    }

    public class MessageModel : IRealtimeMessage
    {
    }
}
