using Microsoft.AspNetCore.Http;

namespace NetworkResurrector.Api.Extensions
{
    public static class HttpRequestExtensions
    {
        private const string SignalRConnectionIdHeader = "SignalR-ConnectionId";

        /// <summary>
        /// Gets the SignalR connection ID from the request headers if present
        /// </summary>
        /// <param name="request">The HTTP request</param>
        /// <returns>The SignalR connection ID or null if not present</returns>
        public static string GetSignalRConnectionId(this HttpRequest request)
        {
            if (request.Headers.TryGetValue(SignalRConnectionIdHeader, out var values))
            {
                return values.ToString();
            }

            return null;
        }
    }
}
