import React from "react";
import { Dashboard, Dns, DeviceHub, Build, Settings, Info, Adb, Notifications, Devices, Stream } from "../../icons";
import env from "utils/env";

const isDevelopment = import.meta.env.DEV || env.NODE_ENV === "development";

type MenuItem = {
  code: string;
  name: string;
  route: string;
  icon: React.ReactElement;
  order: number;
  subMenus?: MenuItem[];
  hidden?: boolean;
};

type MenuSection = {
  order: number;
  items: MenuItem[];
};

type Menu = MenuSection[];

const menu: Menu = [
  {
    order: 0,
    items: [
      {
        code: "dashboard",
        name: "Menu.Dashboard",
        route: "/dashboard",
        icon: <Dashboard />,
        order: 0
      },
      {
        code: "machines",
        name: "Menu.Machines",
        route: "/machines",
        icon: <Dns />,
        order: 1
      },
      {
        code: "system",
        name: "Menu.System",
        route: "/system",
        icon: <DeviceHub />,
        order: 2
      }
    ]
  },
  {
    order: 1,
    items: [
      {
        code: "administration",
        name: "Menu.Administration.Title",
        route: "/administration",
        icon: <Build />,
        order: 0,
        subMenus: [
          {
            code: "machines",
            name: "Menu.Administration.Machines",
            route: "/administration/machines",
            icon: <Devices />,
            order: 0
          },
          {
            code: "agents",
            name: "Menu.Administration.Agents",
            route: "/administration/agents",
            icon: <Stream />,
            order: 1
          }
        ]
      },
      {
        code: "settings",
        name: "Menu.Settings",
        route: "/settings",
        icon: <Settings />,
        order: 1
      },
      {
        code: "debugging",
        name: "Menu.Debugging.Title",
        route: "/debugging",
        icon: <Adb />,
        order: 2,
        hidden: !isDevelopment,
        subMenus: [
          {
            code: "notifications",
            name: "Menu.Debugging.Notifications",
            route: "/debugging/notifications",
            icon: <Notifications />,
            order: 0
          }
        ]
      }
    ]
  },
  {
    order: 2,
    items: [
      {
        code: "about",
        name: "Menu.About",
        route: "/about",
        icon: <Info />,
        order: 0
      }
    ]
  }
];

const filterAndSortMenu = (menuData: Menu): MenuSection[] => {
  return menuData
    .map(section => ({
      ...section,
      items: section.items.filter(item => !item.hidden)
    }))
    .filter(section => section.items.length > 0)
    .sort((a, b) => (a.order || 0) - (b.order || 0));
};

const filteredMenu = filterAndSortMenu(menu);

export type { MenuItem, MenuSection, Menu };
export default filteredMenu;
