import { createContext } from "react";
import { PublishFn, RealtimeNotification, SubscribeFn } from "./types";

export interface RealtimeNotificationsContextData {
  isConnected: boolean;
  connectionId: string | null;
  notifications: RealtimeNotification[];
  subscribe: SubscribeFn;
  publish: PublishFn;

  // nonstandard properties
  messages: string[];
  sendMessage: (message: string) => Promise<void>;
  sendNotification: (notification: RealtimeNotification) => Promise<void>;
  joinGroup: (groupName: string) => Promise<void>;
  sendToGroup: (groupName: string, message: string) => Promise<void>;
  sendToClient: (connectionId: string, message: string) => Promise<void>;
  sendToUser: (userId: string, title: string, message: string) => Promise<void>;
}

const RealtimeNotificationsContext = createContext<RealtimeNotificationsContextData>({
  connectionId: null,
  isConnected: false,
  notifications: [],
  subscribe: () => {
    throw new Error("subscribe function not implemented");
  },
  publish: () => {
    throw new Error("publish function not implemented");
  },

  messages: [],
  sendMessage: async () => {},
  sendNotification: async () => {},
  joinGroup: async () => {},
  sendToGroup: async () => {},
  sendToClient: async () => {},
  sendToUser: async () => {}
});

export default RealtimeNotificationsContext;
