import { useEffect, useMemo } from "react";
import { RealtimeNotification } from "../types";
import useRealtimeNotifications from "./useRealtimeNotifications";

interface SubscriptionOptions<T> {
  skip?: boolean;
  onNotification?: (event: RealtimeNotification<T>) => void;
}

const defaultOptions: Required<SubscriptionOptions<any>> = {
  skip: false,
  onNotification: () => {}
};

function useSubscription<T>(notificationType: string, options: SubscriptionOptions<T> = defaultOptions) {
  const { subscribe } = useRealtimeNotifications();
  const opts = useMemo(() => ({ ...defaultOptions, ...options }), [options]);

  useEffect(() => {
    if (opts.skip) {
      return;
    }

    // Subscribe to the specified notification type with the provided callback
    const unsubscribe = subscribe<T>(notificationType, opts.onNotification);

    // Return an unsubscribe function to be called on component unmount
    return () => {
      unsubscribe();
    };
  }, [subscribe, notificationType, opts.skip, opts.onNotification]);
}

export default useSubscription;
